diff -up lightspark-0.7.2/conf/FindLLVM.cmake.llvm33 lightspark-0.7.2/conf/FindLLVM.cmake
--- lightspark-0.7.2/conf/FindLLVM.cmake.llvm33	2013-03-16 12:19:18.000000000 +0100
+++ lightspark-0.7.2/conf/FindLLVM.cmake	2013-05-11 11:57:36.455450049 +0200
@@ -168,11 +168,16 @@ else (LLVM_INCLUDE_DIR)
 
   set(CMAKE_REQUIRED_INCLUDES ${LLVM_INCLUDE_DIR})
   check_include_file_cxx("llvm/DataLayout.h" HAVE_DATALAYOUT_H)
+  check_include_file_cxx("llvm/IR/DataLayout.h" HAVE_IR_DATALAYOUT_H)
   unset(CMAKE_REQUIRED_INCLUDES)
   MESSAGE(STATUS "HAVE_DATALAYOUT_H: " ${HAVE_DATALAYOUT_H})
+  MESSAGE(STATUS "HAVE_IR_DATALAYOUT_H: " ${HAVE_IR_DATALAYOUT_H})
   IF(HAVE_DATALAYOUT_H)
     ADD_DEFINITIONS(-DHAVE_DATALAYOUT_H)
   ENDIF(HAVE_DATALAYOUT_H)
+  IF(HAVE_IR_DATALAYOUT_H)
+    ADD_DEFINITIONS(-DHAVE_IR_DATALAYOUT_H)
+  ENDIF(HAVE_IR_DATALAYOUT_H)
   
   exec_program(${LLVM_CONFIG_EXECUTABLE} ARGS --cxxflags  OUTPUT_VARIABLE LLVM_COMPILE_FLAGS )
   MESSAGE(STATUS "LLVM CXX flags: " ${LLVM_COMPILE_FLAGS})
diff -up lightspark-0.7.2/src/scripting/abc.cpp.llvm33 lightspark-0.7.2/src/scripting/abc.cpp
--- lightspark-0.7.2/src/scripting/abc.cpp.llvm33	2013-03-16 12:19:18.000000000 +0100
+++ lightspark-0.7.2/src/scripting/abc.cpp	2013-05-11 11:57:36.451450048 +0200
@@ -23,12 +23,19 @@
 
 #include "compat.h"
 
-#include <llvm/Module.h>
 #include <llvm/ExecutionEngine/ExecutionEngine.h>
 #include <llvm/ExecutionEngine/JIT.h>
 #include <llvm/PassManager.h>
-#include <llvm/LLVMContext.h>
-#ifdef HAVE_DATALAYOUT_H
+#ifdef HAVE_IR_DATALAYOUT_H
+#  include <llvm/IR/Module.h>
+#  include <llvm/IR/LLVMContext.h>
+#else
+#  include <llvm/Module.h>
+#  include <llvm/LLVMContext.h>
+#endif
+#ifdef HAVE_IR_DATALAYOUT_H
+#  include <llvm/IR/DataLayout.h>
+#elif defined HAVE_DATALAYOUT_H
 #  include <llvm/DataLayout.h>
 #else
 #  include <llvm/Target/TargetData.h>
@@ -1489,7 +1496,7 @@ void ABCVm::Run(ABCVm* th)
 		assert_and_throw(th->ex);
 
 		th->FPM=new llvm::FunctionPassManager(th->module);
-#ifdef HAVE_DATALAYOUT_H
+#if defined HAVE_DATALAYOUT_H || defined HAVE_IR_DATALAYOUT_H
 		th->FPM->add(new llvm::DataLayout(*th->ex->getDataLayout()));
 #else
 		th->FPM->add(new llvm::TargetData(*th->ex->getTargetData()));
diff -up lightspark-0.7.2/src/scripting/abc_codesynt.cpp.llvm33 lightspark-0.7.2/src/scripting/abc_codesynt.cpp
--- lightspark-0.7.2/src/scripting/abc_codesynt.cpp.llvm33	2013-03-16 12:19:18.000000000 +0100
+++ lightspark-0.7.2/src/scripting/abc_codesynt.cpp	2013-05-11 11:59:23.066458300 +0200
@@ -25,18 +25,29 @@
 #endif
 
 #include "compat.h"
-#include <llvm/Module.h>
-#include <llvm/DerivedTypes.h>
 #include <llvm/ExecutionEngine/ExecutionEngine.h>
 #include <llvm/PassManager.h>
-#include <llvm/Constants.h>
-#ifdef HAVE_IRBUILDER_H
+#ifdef HAVE_IR_DATALAYOUT_H
+#  include <llvm/IR/Constants.h>
+#  include <llvm/IR/DerivedTypes.h>
+#  include <llvm/IR/Module.h>
+#  include <llvm/IR/LLVMContext.h>
+#else
+#  include <llvm/Constants.h>
+#  include <llvm/DerivedTypes.h>
+#  include <llvm/Module.h>
+#  include <llvm/LLVMContext.h>
+#endif
+#ifdef HAVE_IR_DATALAYOUT_H
+#  include <llvm/IR/IRBuilder.h>
+#elif defined HAVE_IRBUILDER_H
 #  include <llvm/IRBuilder.h>
 #else
 #  include <llvm/Support/IRBuilder.h>
 #endif
-#include <llvm/LLVMContext.h>
-#ifdef HAVE_DATALAYOUT_H
+#ifdef HAVE_IR_DATALAYOUT_H
+#  include <llvm/IR/DataLayout.h>
+#elif defined HAVE_DATALAYOUT_H
 #  include <llvm/DataLayout.h>
 #else
 #  include <llvm/Target/TargetData.h>
@@ -279,7 +290,7 @@ void ABCVm::registerFunctions()
 	llvm::FunctionType* FT=NULL;
 
 	//Create types
-#ifdef HAVE_DATALAYOUT_H
+#if defined HAVE_DATALAYOUT_H || defined HAVE_IR_DATALAYOUT_H
 	ptr_type=ex->getDataLayout()->getIntPtrType(llvm_context());
 #else
 	ptr_type=ex->getTargetData()->getIntPtrType(llvm_context());
